import { Grid } from "@mui/material";
import { memo, useEffect, useState } from "react";
import DefaultTask from "../DefaultTask/DefaultTask";

const heightCell = 40
const CalendarStandartCell = ({ children, xs, hours, dayNumber, createTaskInCellHandler, handleOpen, modal, dragTaskHandler, linesInDay, week, copyTask, createCopyTask, month, year }) => {
    const [isThisCell, setIsThisCell] = useState(false)
    const [top, setTop] = useState(0)
    const cellClass = {
        position: 'relative',
        height: linesInDay?.length ? `${heightCell * linesInDay.length + 5}px` : `${45}px`,
        borderRight: '1px solid black',
        borderBottom: week ? '1px solid black' : null,
        transition: '0.3s',
        '&:hover': {
            transition: '0.3s',
            cursor: children ? null : '#d6d2d2',
            background: children ? null : '#d6d2d2'
        },
    }

    useEffect(() => {
        if (!modal) {
            setIsThisCell(false);
        }
    }, [modal])

    const dragOverHandler = (e) => {
        e.preventDefault();
        e.target.style.background = children ? null : '#d6d2d2'
    }
    const dragLeaveHandler = (e) => {
        e.preventDefault();
        e.target.style.background = null
    }

    const dropHandler = (e) => {
        e.stopPropagation()
        e.preventDefault();
        e.target.style.background = null
        dragTaskHandler(dayNumber, parseInt(hours.split(':')[0]), month, year)
    }

    const onClickHandler = (e) => {
        if (!week) {
            if (e.nativeEvent.offsetY <= 5) {
                setTop(40 * Math.ceil((e.nativeEvent.offsetY) / 40 - 1))
            } else {
                setTop(40 * Math.ceil((e.nativeEvent.offsetY - 5) / 40 - 1))
            }
        }
        if (copyTask) {
            createCopyTask(dayNumber, parseInt(hours.split(':')[0]), month, year)
        } else {
            createTaskInCellHandler(dayNumber, hours, month, year);
            setIsThisCell(true);
            handleOpen(e)
        }
    }

    return <>
        <Grid
            item xs={xs}
            sx={cellClass}
            onClick={(e) => { onClickHandler(e) }}
            onDragOver={(e) => { dragOverHandler(e) }}
            onDragLeave={(e) => { dragLeaveHandler(e) }}
            onDrop={(e) => { dropHandler(e) }}
        >
            {children}
            {isThisCell ?
                <DefaultTask week={week} top={top} /> : null}

        </Grid>
    </>
};

export default memo(CalendarStandartCell, (prevProps, nextProps) => {
    if (!prevProps.modal) return false
    if (nextProps.modal) return true
});